@@ -16,6 +16,17 @@ void RSingleTraitMCMCSetup(int *nind,int *nchr,int *ngen, int *nloci,double *loc
 					  int *seed,int *verbose);
 
 
+void RMultipleTraitsMCMCSetup(int *nind,int *nchr,int *ngen,int *npheno,int *nloci,double *loci,double *prob,
+					  double *yvalue,int *multipletrait,int *traittype,int *ncategory,
+					  int *iter,int *thin,int *burnin,int *algorithm,int *genoupdate,
+					  int *epis,int *emainqtl,int *eqtl,int *mnqtl,
+					  double *interval,int *chrnqtl,
+					  int *envi,int *qtl_envi,int *nrancov,int *nfixcov,int *intcov,double *rancoef,double *fixcoef,int *nran,
+					  int *depen,double *prop,
+					  int *seed,int *verbose,
+					  int *diffloc, int *qtlloc);  
+
+
 void RBayesianAnovaSetup( int *nind,int *nchr,int *ngen, int *nloci,double *loci,double *prob,
 					 double *yvalue,int *traittype,int *ncategory,
 					 int *iter,int *thin,int *burnin,
@@ -23,9 +34,13 @@ void RBayesianAnovaSetup( int *nind,int *nchr,int *ngen, int *nloci,double *loci
                      int *epis,int *mnqtl,
 					 double *interval,int *chrnqtl,
 					 int *envi,int *qtl_envi,int *nrancov,int *nfixcov,int *intcov,double *rancoef,double *fixcoef,int *nran,
-				     int *qchr,int *qloc,int *gamma_main,int *gamma_epis,double *gamma_gbye,
+				     int *contrast,
+					 int *qchr,int *qloc,int *gamma_main,int *gamma_epis,double *gamma_gbye,
 					 int *seed,int *verbose );
 
-void ROutputManager(char **iterFile,char **covFile,char **mainFile,char **pairFile,char **gbyeFile,char **devFile);
+
+void ROutputManager(char **iterFile,char **covFile,char **mainFile,char **pairFile,char **gbyeFile,char **devFile,char **sigmaFile);
+
+void R_CheckUserInterrupt(void);
 
 #endif // R_INTERFACES_H
